@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import Union
 from karas.util import BaseModel
-from karas.Sender import Client, Member, Sender, Friend, Subject
+from karas.Sender import Client, Member, Sender, Friend, Subject, Stranger, Group
 from karas.chain import MessageChain
 from karas.elements import ElementBase
 
@@ -73,9 +73,53 @@ class OtherClientMessage(MessageBase):
     sender: Client
     messageChain: MessageChain
 
+class FriendSyncMessage(MessageBase):
+    """好友同步消息"""
+    type: str = "FriendSyncMessage"
+    subject: Friend
+    messageChain: MessageChain
+
+    def __str__(self) -> str:
+        return super().__str__()+": "+self.messageChain.__str__()
+
+
+class GroupSyncMessage(MessageBase):
+    """群组同步消息"""
+    type: str = "GroupSyncMessage"
+    subject: Group
+    messageChain: MessageChain
+
+    def __str__(self) -> str:
+        return super().__str__()+": " + self.messageChain.__str__()
+
+
+class TempSyncMessage(MessageBase):
+    """临时同步消息"""
+    type: str = "TempSyncMessage"
+    subject: Member
+    messageChain: MessageChain
+
+    def __str__(self) -> str:
+        return super().__str__()+": " + self.messageChain.__str__()
+
+
+class StrangerSyncMessage(MessageBase):
+    """陌生人同步消息"""
+    type: str = "StrangerSyncMessage"
+    subject: Stranger
+    messageChain: MessageChain
+
+    def __str__(self) -> str:
+        return super().__str__()+": " + self.messageChain.__str__()
+
+
 
 class MessageEnum(Enum):
     GroupMessage: "GroupMessage" = GroupMessage
     FriendMessage: "FriendMessage" = FriendMessage
     TempMessage: "TempMessage" = TempMessage
     StrangerMessage: "StrangerMessage" = StrangerMessage
+    GroupSyncMessage: "GroupSyncMessage" = GroupSyncMessage
+    FriendSyncMessage: "FriendSyncMessage" = FriendSyncMessage
+    TempSyncMessage: "TempSyncMessage" = TempSyncMessage
+    StrangerSyncMessage: "StrangerSyncMessage" = StrangerSyncMessage
